// index.js
// 获取全局的应用实例
const app = getApp();

// 引入utils全局函数
var dou = require('../../utils/util.js');

Page({
  data: {
    phoneExist: 'no',
    agree: false, // 用户协议
    checkValue: 1,
    showTermCue: false
  },
  
  onLoad: function() {
    var that = this; // this代表着当前的对象，它在程序中随着执行的上下文随时会变化，在success中的this跟这里的已经不是同一个对象
   
    // 预登录
    that.wxLoginPreload()
    
    wx.request({
      url: app.mp_url + 'databox.php?rec=common',
      header: {
        'Connect-Key' : wx.getStorageSync('connect_key')
      },
      success: function(res) {
        that.setData({
          lang: res.data.lang,
          site: res.data.site,
          param: res.data.param
        })
        wx.setNavigationBarTitle({
          title: res.data.site.site_name
        })
      },
    })
  },
 
  onShow: function () {
    var that = this;
   
    wx.request({
      url: app.mp_url + 'user.php?rec=check_login_state',
      data: {
        'user_id': wx.getStorageSync('user_id'),
        'shell': wx.getStorageSync('shell')
      },
      method:'POST',
      header: {
        'Connect-Key' : wx.getStorageSync('connect_key'),
        'Content-Type': 'application/x-www-form-urlencoded'
      },
      success: function (res) {
        if (res.data.phone == 'no') {
          that.setData({
            phoneExist: 'no'
          })
        }
      }
    })
    
    // 在tabBar第三个图标中显示购物车数量
    dou.showCartNumber()
  },

  // 查看是否授权
  wxLogin: function(phone = '') {
    var that = this;
    
    console.log('登录操作开始')
    //1 获取code
    var code='';
    wx.login({
      success(res) {
        if (res.code) {
          wx.request({
            url: app.mp_url + 'user.php?rec=wx_login',
            data: {
              code: res.code,
              phone: phone
            },
            method: 'GET',
            success: function(info) {
              //console.log(info.data) // 点击登录无反应，可以打印查看错误提示
              if (info.data.wrong) {
                dou.douMsg(info.data.wrong)
              } else if (info.data.sns) { // 先将获取的用户信息缓存，然后跳转到注册或者登录页面进行关联绑定
                console.log('绑定页面')
                wx.setStorageSync('sns', JSON.stringify(info.data.sns)) // JSON.stringify()从一个对象中解析出字符串
                wx.navigateTo({
                  url: '/pages/user/sns_link'
                })
              } else if (info.data.bind) { // 成功在用户中心中进行了绑定操作，返回绑定页面
                console.log('用户中心绑定页面')
                wx.navigateTo({
                  url: '/pages/user/sns'
                })
              } else if (info.data.user) { // 登录成功，并返回到会员中心页面
                console.log(info.data)

                // 将登陆成功信息写入小程序本地storage
                wx.setStorageSync('user_id', info.data.user.user_id)
                wx.setStorageSync('shell', info.data.user.shell)

                // 登录成标记
                wx.setStorageSync('loginEd', true)

                // 通信标识
                wx.setStorageSync('connect_key', info.data.user.connect_key)
                wx.setStorageSync('connect_key_time', new Date().getTime()) // 通信标识生成时间

                wx.reLaunch({
                  url: '/pages/user/user'
                })
              }
            }
          })
        } else {
          console.log('登录失败！' + res.errMsg)
        }
      }
    });
  },

  // 查看是否授权
  wxLoginPreload: function() {
    var that = this;
    
    wx.login({
      success(res) {
        if (res.code) {
          wx.request({
            url: app.mp_url + 'user.php?rec=wx_login',
            data: {
              code: res.code,
              act: 'preload'
            },
            method: 'GET',
            success: function(res) {
              if (res.data.wrong) {
                dou.douMsg(res.data.wrong)
              } else {
                that.setData({
                  phoneExist: res.data.phone_exist
                })
              }
            }
          })
        }
      }
    });
  },
 
  // 获取手机号
  getPhoneNumber: function (e) {
    var that = this
    
    console.log('开始获取手机号')
    // 微信需要认证，如果无认证，打印e.detail会提示getPhoneNumber:fail no permission，也就是获取手机号功能为获取批准
    wx.request({
      url: app.mp_url + 'user.php?rec=wx_get_phone',
      data: {
        user_id: wx.getStorageSync('user_id'),
        shell: wx.getStorageSync('shell'),
        code: e.detail.code
      },
      header: {
        'Connect-Key' : wx.getStorageSync('connect_key')
      },
      method: 'GET',
      success: function(res) {
        console.log(res.data);
        if (res.data.wrong == 'ok') {
          that.wxLogin(res.data.phone)
        } else {
          wx.showToast({
              title: res.data.wrong,
              duration: 1000,
              icon: 'error',
              mask: true
          })
        }
      }
    })
  },
 
  login: function (e) {
    var that = this
    
    wx.request({
      url: app.mp_url + 'user.php?rec=login_post',
      data: {
        'email': e.detail.value.email,
        'password': e.detail.value.password,
        'sns': wx.getStorageSync('sns')
      },
      method:'POST',
      header: {
        'Connect-Key' : wx.getStorageSync('connect_key'),
        'Content-Type': 'application/x-www-form-urlencoded'
      },
      success: function (res) {
        // console.log(res.data)
        if (res.data.wrong) {
          that.setData({
            errorMsg: res.data.wrong
          });
        } else {
          // 将登陆成功信息写入小程序本地storage
          wx.setStorageSync('user_id', res.data.user.user_id)
          wx.setStorageSync('shell', res.data.user.shell)

          // 登录成标记
          wx.setStorageSync('loginEd', true)

          // 通信标识
          wx.setStorageSync('connect_key', res.data.user.connect_key)
          wx.setStorageSync('connect_key_time', new Date().getTime()) // 通信标识生成时间
          
          // 跳转到会员中心页
          wx.reLaunch({
            url: '/pages/user/user'
          })
        }
      }
   })
  },
  
  agreeTerm(e) {
    console.log(e.detail.value.includes('1'))
    if (e.detail.value.includes('1')) {
      this.setData({
        agree: true,
        showTermCue: false
      });
    } else {
      this.setData({
        agree: false,
      });
    }
  },
  
  termCue(e) {
    this.setData({
      showTermCue: true,
    });
  },
 
  // 非tabBar的页面，可以带参数
  douNavigateTo: function(e) {
    var url = e.currentTarget.dataset.url;
    wx.navigateTo({
      url: url
    })
  },

  // 只能跳转到tabBar配置页面
  douSwitchTab: function(e) {
    var url = e.currentTarget.dataset.url;
    wx.switchTab({
      url: url
    })
  },



})